@@ -1,4 +1,7 @@
 # __init__.py
 from .fluidbalance import get_fluidbalance
 from .plotting import outliers_histogram
-from .dictionary import get_dictionary
\ No newline at end of file
+from .dictionary import get_dictionary
+from .bigquery import pg2bq
+from .cohorts import *
+from .scores import *
